..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. include:: ../README.rst

.. toctree::
    :maxdepth: 2

    quickstart/index.rst
    datamodel/build-a-datamodel
    tutorial-module/index
    invenio-modules.rst
    application-architecture.rst
    migrating.rst
    orcid-login.rst
    history.rst
    releases/index.rst
    community/index.rst
